==> resin-3.1.13-src.tar.gz: resin-3.1.13/modules/resin/src/com/caucho/servlets/ssi/SetStatement.java <==
/*
 * Copyright (c) 1998-2008 Caucho Technology -- all rights reserved
 *
 * This file is part of Resin(R) Open Source
 *
 * Each copy or derived work must preserve the copyright notice and this
 * notice unmodified.
 *
 * Resin Open Source is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Resin Open Source is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE, or any warranty
 * of NON-INFRINGEMENT.  See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Resin Open Source; if not, write to the
 *
 *   Free Software Foundation, Inc.
 *   59 Temple Place, Suite 330
 *   Boston, MA 02111-1307  USA
 *
 * @author Scott Ferguson
 */

package com.caucho.servlets.ssi;

import com.caucho.vfs.Path;
import com.caucho.vfs.WriteStream;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.IOException;
import java.util.HashMap;

/**
 * Represents a SSI set statement
 */
public class SetStatement extends Statement{
  private final String _var;
  private final SSIExpr _value;

  private SetStatement(String var, SSIExpr value)
  {
    _var = var;
    _value = value;
  }

  static Statement create(HashMap<String,String> attr, Path path)
  {
    String var = attr.get("var");

    if (var == null)
      return new ErrorStatement("['var' is a required attribute of #set]");

    String value = attr.get("value");

    if (value == null)
      return new ErrorStatement("['value' is a required attribute of #set]");

    return new SetStatement(var, ExprParser.parseString(value, path));
  }
  
  /**
   * Executes the SSI statement.
   *
   * @param out the output stream
   * @param request the servlet request
   * @param response the servlet response
   */
  public void apply(WriteStream out,
		    HttpServletRequest request,
		    HttpServletResponse response)
    throws IOException, ServletException
  {
    request.setAttribute(_var, _value.evalString(request, response));
  }
}

==> resin-4.0.66-src.tar.gz: resin-4.0.66/modules/resin/src/com/caucho/servlets/ssi/SetStatement.java <==
/*
 * Copyright (c) 1998-2018 Caucho Technology -- all rights reserved
 *
 * This file is part of Resin(R) Open Source
 *
 * Each copy or derived work must preserve the copyright notice and this
 * notice unmodified.
 *
 * Resin Open Source is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Resin Open Source is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE, or any warranty
 * of NON-INFRINGEMENT.  See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Resin Open Source; if not, write to the
 *
 *   Free Software Foundation, Inc.
 *   59 Temple Place, Suite 330
 *   Boston, MA 02111-1307  USA
 *
 * @author Scott Ferguson
 */

package com.caucho.servlets.ssi;

import com.caucho.vfs.Path;
import com.caucho.vfs.WriteStream;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.IOException;
import java.util.HashMap;

/**
 * Represents a SSI set statement
 */
public class SetStatement extends Statement{
  private final String _var;
  private final SSIExpr _value;

  private SetStatement(String var, SSIExpr value)
  {
    _var = var;
    _value = value;
  }

  static Statement create(HashMap<String,String> attr, Path path)
  {
    String var = attr.get("var");

    if (var == null)
      return new ErrorStatement("['var' is a required attribute of #set]");

    String value = attr.get("value");

    if (value == null)
      return new ErrorStatement("['value' is a required attribute of #set]");

    return new SetStatement(var, ExprParser.parseConcat(value, path));
  }
  
  /**
   * Executes the SSI statement.
   *
   * @param out the output stream
   * @param request the servlet request
   * @param response the servlet response
   */
  public void apply(WriteStream out,
                    HttpServletRequest request,
                    HttpServletResponse response)
    throws IOException, ServletException
  {
    request.setAttribute(_var, _value.evalString(request, response));
  }
}
